@@ -14,7 +14,7 @@ along with this library; if not, write to the Free Software Foundation, Inc.,
 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301  USA
 **********/
 // "mTunnel" multicast access service
-// Copyright (c) 1996-2019 Live Networks, Inc.  All rights reserved.
+// Copyright (c) 1996-2020 Live Networks, Inc.  All rights reserved.
 // IO event handlers
 // Implementation
 
@@ -37,7 +37,7 @@ static unsigned char ioBuffer[ioBufferSize];
 
 void socketReadHandler(Socket* sock, int /*mask*/) {
   unsigned bytesRead;
-  struct sockaddr_in fromAddress;
+  struct sockaddr_storage fromAddress;
   UsageEnvironment& saveEnv = sock->env();
       // because handleRead(), if it fails, may delete "sock"
   if (!sock->handleRead(ioBuffer, ioBufferSize, bytesRead, fromAddress)) {
