@@ -14,7 +14,7 @@ along with this library; if not, write to the Free Software Foundation, Inc.,
 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301  USA
 **********/
 // "mTunnel" multicast access service
-// Copyright (c) 1996-2019 Live Networks, Inc.  All rights reserved.
+// Copyright (c) 1996-2020 Live Networks, Inc.  All rights reserved.
 // Network Addresses
 // Implementation
 
@@ -85,15 +85,25 @@ void NetAddress::clean() {
 
 NetAddressList::NetAddressList(char const* hostname)
   : fNumAddresses(0), fAddressArray(NULL) {
-  // First, check whether "hostname" is an IP address string:
-  netAddressBits addr = our_inet_addr((char*)hostname);
-  if (addr != INADDR_NONE) {
-    // Yes, it was an IP address string.  Return a 1-element list with this address:
+  // First, check whether "hostname" is an IP address string (check IPv4, then IPv6).
+  // If so, return a 1-element list with this address:
+  ipv4AddressBits addr4;
+  if (inet_pton(AF_INET, hostname, (u_int8_t*)&addr4) == 1) {
     fNumAddresses = 1;
     fAddressArray = new NetAddress*[fNumAddresses];
     if (fAddressArray == NULL) return;
 
-    fAddressArray[0] = new NetAddress((u_int8_t*)&addr, sizeof (netAddressBits));
+    fAddressArray[0] = new NetAddress((u_int8_t*)&addr4, sizeof addr4);
+    return;
+  }
+
+  ipv6AddressBits addr6;
+  if (inet_pton(AF_INET6, hostname, (u_int8_t*)&addr6) == 1) {
+    fNumAddresses = 1;
+    fAddressArray = new NetAddress*[fNumAddresses];
+    if (fAddressArray == NULL) return;
+
+    fAddressArray[0] = new NetAddress((u_int8_t*)&addr6, sizeof addr6);
     return;
   }
     
@@ -292,21 +302,60 @@ Boolean IsMulticastAddress(netAddressBits address) {
 AddressString::AddressString(struct sockaddr_in const& addr) {
   init(addr.sin_addr.s_addr);
 }
-
 AddressString::AddressString(struct in_addr const& addr) {
   init(addr.s_addr);
 }
-
-AddressString::AddressString(netAddressBits addr) {
+AddressString::AddressString(ipv4AddressBits const& addr) {
   init(addr);
 }
 
-void AddressString::init(netAddressBits addr) {
-  fVal = new char[16]; // large enough for "abc.def.ghi.jkl"
-  netAddressBits addrNBO = htonl(addr); // make sure we have a value in a known byte order: big endian
-  sprintf(fVal, "%u.%u.%u.%u", (addrNBO>>24)&0xFF, (addrNBO>>16)&0xFF, (addrNBO>>8)&0xFF, addrNBO&0xFF);
+AddressString::AddressString(struct sockaddr_in6 const& addr) {
+  init(addr.sin6_addr.s6_addr);
+}
+AddressString::AddressString(struct in6_addr const& addr) {
+  init(addr.s6_addr);
+}
+AddressString::AddressString(ipv6AddressBits const& addr) {
+  init(addr);
+}
+
+AddressString::AddressString(struct sockaddr_storage const& addr) {
+  switch (addr.ss_family) {
+    case AF_INET: {
+      init(((sockaddr_in*)&addr)->sin_addr.s_addr);
+      break;
+    }
+    case AF_INET6: {
+      init(((sockaddr_in6*)&addr)->sin6_addr.s6_addr);
+      break;
+    }
+  }
+}
+
+void AddressString::init(ipv4AddressBits const& addr) {
+  fVal = new char[INET_ADDRSTRLEN];
+  inet_ntop(AF_INET, &addr, fVal, INET_ADDRSTRLEN);
+}
+
+void AddressString::init(ipv6AddressBits const& addr) {
+  fVal = new char[INET6_ADDRSTRLEN];
+  inet_ntop(AF_INET6, &addr, fVal, INET6_ADDRSTRLEN);
 }
 
 AddressString::~AddressString() {
   delete[] fVal;
 }
+
+portNumBits portNum(struct sockaddr_storage const& addr) {
+  switch (addr.ss_family) {
+    case AF_INET: {
+      return ((sockaddr_in*)&addr)->sin_port;
+    }
+    case AF_INET6: {
+      return ((sockaddr_in6*)&addr)->sin6_port;
+    }
+    default: {
+      return 0;
+    }
+  }
+}
