@@ -14,7 +14,7 @@ along with this library; if not, write to the Free Software Foundation, Inc.,
 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301  USA
 **********/
 // "liveMedia"
-// Copyright (c) 1996-2019 Live Networks, Inc.  All rights reserved.
+// Copyright (c) 1996-2020 Live Networks, Inc.  All rights reserved.
 // A 'ServerMediaSubsession' object that creates new, unicast, "RTPSink"s
 // on demand, from an incoming UDP (or RTP/UDP) MPEG-2 Transport Stream
 // Implementation
@@ -54,7 +54,11 @@ FramedSource* MPEG2TransportUDPServerMediaSubsession
   if (fInputGroupsock == NULL) {
     // Create a 'groupsock' object for receiving the input stream:
     struct in_addr inputAddress;
-    inputAddress.s_addr = fInputAddressStr == NULL ? 0 : our_inet_addr(fInputAddressStr);
+    if (fInputAddressStr == NULL) {
+      inputAddress.s_addr = 0;
+    } else {
+      if (inet_pton(AF_INET, fInputAddressStr, &inputAddress.s_addr) != 1) return NULL;
+    }
     fInputGroupsock = new Groupsock(envir(), inputAddress, fInputPort, 255);
   }
 
