@@ -304,11 +304,20 @@ Boolean RTSPClient::parseRTSPURL(char const* url,
 
     // Next, parse <server-address-or-name>
     char* to = &parseBuffer[0];
+    Boolean isInSquareBrackets = False; //  by default
+    if (*from == '[') {
+      ++from;
+      isInSquareBrackets = True;
+    }
     unsigned i;
     for (i = 0; i < parseBufferSize; ++i) {
-      if (*from == '\0' || *from == ':' || *from == '/') {
+      if (*from == '\0' ||
+	  (*from == ':' && !isInSquareBrackets) ||
+	  *from == '/' ||
+	  (*from == ']' && isInSquareBrackets)) {
 	// We've completed parsing the address
 	*to = '\0';
+	if (*from == ']' && isInSquareBrackets) ++from;
 	break;
       }
       *to++ = *from++;
@@ -749,7 +758,7 @@ Boolean RTSPClient::setRequestFields(RequestRecord* request,
     netAddressBits serverAddress = *(netAddressBits*)(destAddress.data());
     AddressString serverAddressString(serverAddress);
     
-    protocolStr = "HTTP/1.1";
+    protocolStr = "HTTP/1.0";
     
     if (strcmp(request->commandName(), "GET") == 0) {
       // Create a 'session cookie' string, using MD5:
@@ -1977,7 +1986,7 @@ int RTSPClient::read(u_int8_t* buffer, unsigned bufferSize) {
   if (fTLS.isNeeded) {
     return fTLS.read(buffer, bufferSize);
   } else {
-    struct sockaddr_in dummy; // 'from' address - not used
+    struct sockaddr_storage dummy; // 'from' address - not used
     return readSocket(envir(), fInputSocketNum, buffer, bufferSize, dummy);
   }
 }
