@@ -13,7 +13,7 @@ You should have received a copy of the GNU Lesser General Public License
 along with this library; if not, write to the Free Software Foundation, Inc.,
 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301  USA
 **********/
-// Copyright (c) 1996-2019, Live Networks, Inc.  All rights reserved
+// Copyright (c) 1996-2020, Live Networks, Inc.  All rights reserved
 // A test program that reads a MPEG-1 or 2 Video Elementary Stream file,
 // and streams it using RTP
 // main program
@@ -73,7 +73,7 @@ int main(int argc, char** argv) {
   const unsigned char ttl = 7; // low, in case routers don't admin scope
 
   struct in_addr destinationAddress;
-  destinationAddress.s_addr = our_inet_addr(destinationAddressStr);
+  (void)inet_pton(AF_INET, destinationAddressStr, &destinationAddress.s_addr);
   const Port rtpPort(rtpPortNum);
   const Port rtcpPort(rtcpPortNum);
 
