@@ -13,7 +13,7 @@ You should have received a copy of the GNU Lesser General Public License
 along with this library; if not, write to the Free Software Foundation, Inc.,
 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301  USA
 **********/
-// Copyright (c) 1996-2019, Live Networks, Inc.  All rights reserved
+// Copyright (c) 1996-2020, Live Networks, Inc.  All rights reserved
 // A test program that receives a UDP multicast stream
 // and retransmits it to another (multicast or unicast) address & port
 // main program
@@ -40,7 +40,7 @@ int main(int argc, char** argv) {
     = "239.255.42.42";
 #endif
   struct in_addr inputAddress;
-  inputAddress.s_addr = our_inet_addr(inputAddressStr);
+  (void)inet_pton(AF_INET,  inputAddressStr, &inputAddress.s_addr);
 
   Port const inputPort(8888);
   unsigned char const inputTTL = 0; // we're only reading from this mcast group
@@ -49,7 +49,7 @@ int main(int argc, char** argv) {
   char* sourceAddressStr = "aaa.bbb.ccc.ddd";
                            // replace this with the real source address
   struct in_addr sourceFilterAddress;
-  sourceFilterAddress.s_addr = our_inet_addr(sourceAddressStr);
+  (void)inet_pton(AF_INET, sourceAddressStr, &sourceFilterAddress.s_addr);
 
   Groupsock inputGroupsock(*env, inputAddress, sourceFilterAddress, inputPort);
 #else
@@ -66,7 +66,7 @@ int main(int argc, char** argv) {
     // (or unicast address), but do *not* change it to use the same multicast
     // address as "inputAddressStr".
   struct in_addr outputAddress;
-  outputAddress.s_addr = our_inet_addr(outputAddressStr);
+  (void)inet_pton(AF_INET, outputAddressStr, &outputAddress.s_addr);
 
   Port const outputPort(4444);
   unsigned char const outputTTL = 255;
